@@ -54,6 +54,8 @@
 ( cd opt/kde/share/doc/HTML/en/ktimer ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kcharselect ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/superkaramba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/superkaramba ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/KRegExpEditor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kinfocenter/blockdevices ; rm -rf common )
